pub struct Font { /* private fields */ }
Represents a font family name along with the font glyph source.

Implementations

Noto Sans Regular - an open-source used by Linux and Google.

Emulogic - a bold, retro gaming pixel font by Freaky Fonts.

Inconsolata - an open-source monospace font designed for source code and terminals.

Constructs a new Font instance with a given name.

Constructs a new Font instance from a static byte array.

Constructs a new Font instance from a file.

Returns the name of the font family.

Returns the hashed identifier for this font family.