Module image

Module image 

Image and PixelFormat functions.

Structs

Bytes
An iterator over the bytes of an Image.
Image
An Image representing a buffer of pixel color values.
Pixels
An iterator over the Color pixels of an Image.

Enums

Icon
Represents an image icon source.
PixelFormat
Format for interpreting image data.