Settings methods for the PixEngine.

Methods for reading and setting various engine configuration values.

Provided types:

  • DrawMode: Determines how (x, y) coordinates are used for rendering.
  • RectMode: Alias for DrawMode.
  • EllipseMode: Alias for DrawMode.
  • ImageMode: Alias for DrawMode.
  • ArcMode: Determines how arcs are rendered.
  • BlendMode: Determines how images and textures are blended.
  • AngleMode: Determines how angles are interpreted.
  • FontStyle: Determines how text is rendered.

Provided PixState methods:

Structs

Font style for drawing text.

Enums

Determines how angles are interpreted.

Drawing mode which determines how arcs are drawn.

Drawing mode which determines how textures are blended together.

Drawing mode which changes how (x, y) coordinates are interpreted.

Type Definitions

Drawing mode which determines how (x, y) coordinates are interpreted when drawing Ellipses.

Drawing mode which determines how (x, y) coordinates are interpreted when drawing Images.

Drawing mode which determines how (x, y) coordinates are interpreted when drawing Rects.