#[non_exhaustive]pub enum ArcMode {
Default,
Pie,
}Expand description
Drawing mode which determines how arcs are drawn.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Default
Draws arc as an open, unfilled pie segment using stroke color.
Pie
Draws arc as a closed pie segment using stroke and fill colors.